@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.45";
+our $VERSION = "0.99";
 
 =encoding utf-8
 
@@ -16,7 +16,7 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.45
+Version 0.99
 
 =head1 DESCRIPTION
 
@@ -380,8 +380,8 @@ This option forces to update cache file even if it is not necessary.
 =head1 COMMAND LINE INTERFACE
 
 You can easily use this module from the command line by using the
-C<xlate> command included in the distribution. See the C<xlate> help
-information for usage.
+C<xlate> command included in the distribution.  See the C<xlate> man
+page for usage.
 
 The C<xlate> command works in concert with the Docker environment, so
 even if you do not have anything installed on hand, you can use it as
@@ -407,35 +407,45 @@ Read Japanese article in L</SEE ALSO> section for detail.
         -a   use API
         -c   just check translation area
         -r   refresh cache
+        -u   force update cache
         -s   silent mode
-        -e # translation engine (default "deepl")
+        -e # translation engine (*deepl, gpt3, gpt4, gpt4o)
         -p # pattern to determine translation area
         -x # file containing mask patterns
         -w # wrap line by # width
-        -o # output format (default "xtxt", or "cm", "ifdef")
+        -o # output format (*xtxt, cm, ifdef, space, space+, colon)
         -f # from lang (ignored)
         -t # to lang (required, no default)
         -m # max length per API call
         -l # show library files (XLATE.mk, xlate.el)
-        --   terminate option parsing
+        --   end of option
+        N.B. default is marked as *
+
     Make options
         -M   run make
         -n   dry-run
+
     Docker options
+        -D * run xlate on the container with the same parameters
+        -C * execute following command on the container, or run shell
+        -A * attach to the live container
+        N.B. -D/-C/-A terminates option handling
+
         -G   mount git top-level directory
-        -B   run in non-interactive (batch) mode
+        -H   mount home directory
+        -V # specify mount directory
+        -U   do not mount
         -R   mount read-only
-        -E * specify environment variable to be inherited
-        -I * docker image name or version (default: tecolicom/xlate:version)
-        -D * run xlate on the container with the rest parameters
-        -C * run following command on the container, or run shell
-    
+        -K   do not remove and keep live container
+        -Q   quit and remove live container
+        -E # specify environment variable to be inherited
+        -I # docker image or version (default: tecolicom/xlate:version)
+
     Control Files:
         *.LANG    translation languates
         *.FORMAT  translation foramt (xtxt, cm, ifdef, colon, space)
         *.ENGINE  translation engine (deepl, gpt3, gpt4, gpt4o)
 
-
 =head1 EMACS
 
 Load the F<xlate.el> file included in the repository to use C<xlate>
